==> haskell-non-negative-0.1.2-344.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-4EIm4qYtM6XEFQ8Xznw2Yq
key:                  non-negative-0.1.2-4EIm4qYtM6XEFQ8Xznw2Yq
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  b4542f049014907c367f91e0c40d1995
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-4EIm4qYtM6XEFQ8Xznw2Yq
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    utility-ht-0.0.17.2-FCtUbDIssee2G1L1Lv2g90

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-345-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-7GbSLXzHZj1Cfy4qsgHhMB
key:                  non-negative-0.1.2-7GbSLXzHZj1Cfy4qsgHhMB
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  5a8fed6a8bf4cd72d345d786c74ef7aa
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-7GbSLXzHZj1Cfy4qsgHhMB
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    utility-ht-0.0.17.2-9ryTCp5DXpz5HmwvPaZxIP

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
